==> phpaga-0.3.tar.bz2: phpaga-0.3/htdocs/countries.php <==
<?php
/**
 * phpaga
 *
 * Countries
 *
 * This is the countries management interface.
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id: countries.php 726 2006-08-05 22:34:30Z florian $
 *
 * Copyright (c) 2002, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

include_once("./config.php");
phpaga_user_pageperm(PHPAGA_PERM_MANAGE_SYSSETTINGS);

$rows = array();
$ctr_name = "";
$ctr_code = "";

phpaga_header(array("menuitem" => "administration"));

if (isset($_REQUEST["action"]) && strlen($_REQUEST["action"]))
{

    switch ($_REQUEST["action"])
    {

        case ACTION_ADD:

            /* add a new country */

            if (isset($_REQUEST["ctr_name"])
                && strlen($_REQUEST["ctr_name"])
                && isset($_REQUEST["ctr_code"])
                && strlen($_REQUEST["ctr_code"]))
            {
                $result = phpaga_countries_addCountry($_REQUEST["ctr_name"], $_REQUEST["ctr_code"]);

                if ($result != PHPAGA_ERR_NONE)
                {
                    phpaga_error ($result);
                    $ctr_name = $_REQUEST["ctr_name"];
                    $ctr_code = $_REQUEST["ctr_code"];
                }
                else
                {
                    phpaga_message(_("Country added"),
                                   _("The country has been inserted successfully."));
                }
            }
            else
            {
                phpaga_message(_("Unable to add country"),
                               _("The country can not be added - please check if you gave it a valid name and country code."));
                $ctr_name = $_REQUEST["ctr_name"];
                $ctr_code = $_REQUEST["ctr_code"];
            }
            break;

        case ACTION_DELETE:

            /* delete a country */

            if (isset($_REQUEST["id"]) && strlen($_REQUEST["id"]))
            {
                $result = phpaga_countries_deleteCountry($_REQUEST["id"]);

                if ($result != PHPAGA_ERR_NONE)
                {

                    /* if we could not delete the record because of
                     * dependencies then use a more descriptive
                     * error message
                     */

                    if ($result == PHPAGA_ERR_DEL_DEPENDENCIES)
                    {
                        $result =
                            _("The country cannot be deleted, as it is still used by some persons or companies.");
                    }

                    phpaga_error($result);
                }
                else
                {
                    phpaga_message(_("Country deleted"),
                                   _("The country has been successfully deleted."));
                }
            }
            break;

        default:
            break;
    }
}

$result = phpaga_countries_getCountries($rows);

if ($result != PHPAGA_ERR_NONE)
{
    phpaga_error($result);
}

$countries_tpl = new psmarty;

$countries_tpl->assign("FORM_ACTION",
                       basename($_SERVER["PHP_SELF"]));
$countries_tpl->assign("ctr_name", $ctr_name);
$countries_tpl->assign("ctr_code", $ctr_code);
$countries_tpl->assign("rows", $rows);

$countries_tpl->display("countries.tpl.html");

phpaga_footer();

?>

==> phpaga-0.6.tar.bz2: phpaga-0.6/htdocs/countries.php <==
<?php
/**
 * phpaga
 *
 * Countries
 *
 * This is the countries management interface.
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id$
 *
 * Copyright (c) 2002, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

include_once("./config.php");
phpaga_user_pageperm(PHPAGA_PERM_MANAGE_SYSSETTINGS);

$rows = array();
$ctr_name = "";
$ctr_code = "";

phpaga_header(array("menuitem" => "administration"));

if (isset($REQUEST_DATA["action"]) && strlen($REQUEST_DATA["action"]))
{

    switch ($REQUEST_DATA["action"])
    {

        case ACTION_ADD:

            if (isset($REQUEST_DATA["ctr_name"])
                && strlen($REQUEST_DATA["ctr_name"])
                && isset($REQUEST_DATA["ctr_code"])
                && strlen($REQUEST_DATA["ctr_code"]))
            {
                $result = phpaga_countries_addCountry($REQUEST_DATA["ctr_name"], $REQUEST_DATA["ctr_code"]);

                if (PhPagaError::isError($result))
                {
                    $result->printMessage();
                    $ctr_name = $REQUEST_DATA["ctr_name"];
                    $ctr_code = $REQUEST_DATA["ctr_code"];
                }
                else
                {
                    phpaga_message(_("Country added"),
                                   _("The country has been inserted successfully."));
                }
            }
            else
            {
                phpaga_message(_("Unable to add country"),
                               _("The country can not be added - please check if you gave it a valid name and country code."));
                $ctr_name = $REQUEST_DATA["ctr_name"];
                $ctr_code = $REQUEST_DATA["ctr_code"];
            }
            break;

        case ACTION_DELETE:

            if (isset($REQUEST_DATA["id"]) && strlen($REQUEST_DATA["id"]))
            {
                $result = phpaga_countries_deleteCountry($REQUEST_DATA["id"]);
                if (PhPagaError::isError($result)) {

                    if ($result->getCode() == PHPAGA_ERR_DEL_DEPENDENCIES)
                        phpaga_error( _("The country cannot be deleted, as it is still used by some persons or companies."));
                    else
                        $result->printMessage();
                }
                else
                    phpaga_message(_("Country deleted"), _("The country has been successfully deleted."));
            }
            break;

        default:
            break;
    }
}

$rows = phpaga_countries_getCountries();

if (PhPagaError::isError($rows))
    $rows->printMessage();

$tpl = new psmarty;

$tpl->assign("FORM_ACTION", basename($_SERVER["PHP_SELF"]));
$tpl->assign("ctr_name", $ctr_name);
$tpl->assign("ctr_code", $ctr_code);
$tpl->assign("rows", $rows);

$tpl->display("countries.tpl.html");

phpaga_footer();

?>
